# passwd
[![Testing with pytest](https://github.com/bsoyka/passwd/workflows/Testing%20with%20pytest/badge.svg?event=push)](https://github.com/bsoyka/passwd/actions)
[![Version 0.3.0](https://img.shields.io/badge/version-0.3.0-orange)](https://github.com/bsoyka/passwd/releases/tag/v0.3.0)
[![MIT License](https://img.shields.io/pypi/l/passwd)](LICENSE)
[![Docs on GitHub](https://img.shields.io/badge/docs-on%20github-blue)](https://github.com/bsoyka/passwd/wiki)
[![GitHub Issues](https://img.shields.io/github/issues/bsoyka/passwd)](https://github.com/bsoyka/passwd/issues)
[![Chat on Gitter](https://img.shields.io/gitter/room/bsoyka/passwd)](https://gitter.im/bsoyka/passwd)

Assorted utilities for gracefully handling and generating passwords

## Contributing
Please see the [code of conduct](CODE_OF_CONDUCT.md) and [contributing guidelines](CONTRIBUTING.md) for information on contributing to `passwd`.

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-2-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://bsoyka.github.io"><img src="https://avatars0.githubusercontent.com/u/37779854?v=4" width="100px;" alt=""/><br /><sub><b>Ben Soyka</b></sub></a><br /><a href="https://github.com/bsoyka/passwd/commits?author=bsoyka" title="Code">💻</a> <a href="#ideas-bsoyka" title="Ideas, Planning, & Feedback">🤔</a> <a href="#maintenance-bsoyka" title="Maintenance">🚧</a> <a href="https://github.com/bsoyka/passwd/commits?author=bsoyka" title="Tests">⚠️</a> <a href="https://github.com/bsoyka/passwd/commits?author=bsoyka" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/echang97"><img src="https://avatars3.githubusercontent.com/u/51372089?v=4" width="100px;" alt=""/><br /><sub><b>echang97</b></sub></a><br /><a href="https://github.com/bsoyka/passwd/commits?author=echang97" title="Code">💻</a> <a href="https://github.com/bsoyka/passwd/commits?author=echang97" title="Tests">⚠️</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!